***USER SHOULD SET DIRECTORY TO FOLDER WHERE replication_data.dta FILE IS LOCATED***
***That folder should include an (empty) subfolder named "tables"***
cd ""

set matsize 2000
/* PREPARE REPLICATION DATASET
//Open private dataset 
use "final_data_private.dta", clear
//drop cases not sent with valid SSI ID
drop if psid==""
//strip out private/unused variables
keep inthissituationdoyouthinkthesena basedonwhatyoureadhowwouldyourat doyouhappentorecallwhetherthesen rep_policy Requiringtransgenderindividualst IncreasingtheminimumwagePleasete Reducingfederalspendingonfarmsub rep_vote rep_promise  rep_state rep_base state_text base_text wouldyoucallyourselfastrongdemoc wouldyoucallyourselfastrongrepub doyouthinkofyourselfasclosertoth ifyouhadtochoosewhichpartywouldy educ income incomemis age r_* female region_* howinterestedareyouinpoliticsand 

save "replication_data.dta", replace
*/

******************************************************
**** BEGIN PUBLIC REPLICATION CODE *******************
******************************************************
use "replication_data.dta", clear
//set directory so tables/figures exported to a subdirectory
cd "tables"
//recode political interest and PID variables
rename howinterestedareyouinpoliticsand interest
label var interest "Interest in Politics (1-3)"
*party ID
//create party identification variable by "averaging" responses to the strength and leaning questions; note: only one of these questions was asked to each R so effectively taking single observed value across questions
egen partyid=rmean(wouldyoucallyourselfastrongdemoc wouldyoucallyourselfastrongrepub doyouthinkofyourselfasclosertoth ifyouhadtochoosewhichpartywouldy)
//collapse 'had to choose' respondents (atypical distinction included for other study) into "pure independents"
replace partyid = 0 if partyid<1 & partyid>-1
//create three point PID variable
recode partyid (-3/-1=1) (0=2) (1/3=3) (*=.), gen(pid3)
label var partyid "Party Identification (-3 = Str. Dem.; 3 = Str. Rep)"
label var pid3 "Party Identification (1 = Dem.; 3 = Rep)"

*********treatments (converting text values to numeric); tabluate text field/variable and generate indicators for each possible text value
*rep vote treatment
tab rep_vote, gen(trt_rep_vote_)
drop trt_rep_vote_1
recode trt_rep_vote_2 (0=-1)
rename trt_rep_vote_2 trt_rep_vote
label var trt_rep_vote "Rep. Vote (-1 = against; 1 = for)"

*rep promise treatment
tab rep_promise, gen(trt_rep_promise_)
drop trt_rep_promise_1
recode trt_rep_promise_2 (0=-1)
rename trt_rep_promise_2 trt_rep_promise
label var trt_rep_promise "Campaign Promise (-1 = oppose; 1 = support)"

*state position treatment
tab rep_state, gen(trt_rep_state_)
drop trt_rep_state_1
recode trt_rep_state_2 (0=-1)
rename  trt_rep_state_2 trt_rep_state
replace trt_rep_state=0 if state_text==""
label var trt_rep_state "State Position (-1 = oppose; 0 = NA; 1 = support)"

*base position treatment
tab rep_base, gen(trt_rep_base_)
drop trt_rep_base_1
recode trt_rep_base_2 (0=-1)
rename  trt_rep_base_2 trt_rep_base
replace trt_rep_base=0 if base_text==""
label var trt_rep_base "Base Position (-1 = oppose; 0 = NA; 1 = support)"

*code respondent policy attitudes 
gen pol_attitude=Requiringtransgenderindividualst 
replace pol_attitude=IncreasingtheminimumwagePleasete if rep_policy=="increase the minimum wage"
replace pol_attitude=Reducingfederalspendingonfarmsub if rep_policy=="reduce federal spending on farm subsidies"
recode pol_attitude (1/3=-1) (4/6=1), gen(resp_pol_supp)
recode pol_attitude (1 6 = 2) (2 5 = 1) (3/4=0), gen(str_polatt)
replace pol_attitude = (pol_attitude-1)/5
label var pol_attitude "Resp. Support for Policy (0-1)"

gen trt_policy_agree=resp_pol_supp*trt_rep_vote 

gen trt_vote_w_base=trt_rep_base*trt_rep_vote
gen trt_vote_w_state=trt_rep_state*trt_rep_vote
gen trt_vote_w_promise=trt_rep_promise*trt_rep_vote
recode trt_vote_w_promise (-1=0)
label var trt_vote_w_promise "Vote Aligned with Promise (1=yes)"
recode trt_policy (-1=0)
label var trt_policy_agree "Vote Aligned with Respondent Preferences (1=yes)"
label var trt_vote_w_state "Vote Aligned with State (-1 = no; 0 = N/A; 1 = yes)"
label var trt_vote_w_base "Vote Aligned with Base (-1 = no; 0 = N/A; 1 = yes)"
//set alignment to be 0-1
replace trt_vote_w_state=(trt_vote_w_state+1)/2
replace trt_vote_w_base=(trt_vote_w_base+1)/2
label var trt_vote_w_state "Vote Aligned with State (0 = no; .5 = N/A; 1 = yes)"
label var trt_vote_w_base "Vote Aligned with Base (0 = no; .5 = N/A; 1 = yes)"
*rescale to 0/1 now that done flipping to handle direction of Senator's vote
recode trt_rep_promise (-1=0)
replace trt_rep_base =(trt_rep_base+1)/2
replace trt_rep_state =(trt_rep_state+1)/2
label var trt_rep_promise "Campaign Promise (0 = oppose; 1 = support)"
label var trt_rep_base "Base Position (0 = oppose; .5 = NA; 1 = support)"
label var trt_rep_state "State Position (0 = oppose; .5 = NA; 1 = support)"

*policy indicators
tab rep_policy, gen(policy_)
label var policy_1 "Policy: Minimum Wage"
label var policy_2 "Policy: Farm Subsidies"
label var policy_3 "Policy: Transgender Bathrooms"
egen policy_cats=group(rep_policy)



***DV RECODING/LABELLING
rename basedonwhatyoureadhowwouldyourat rate_rep
label var rate_rep "Rate Job Senator Doing (0-100)" 
gen rep_should_for=inthissituationdoyouthinkthesena
label var rep_should_for "In This Situation Senator Should Vote (0 [against] - 100 [for])"
gen rate_rep_for=rate_rep
replace rate_rep_for=abs(rate_rep-100) if rep_vote=="against"
gen summ_should_for=(rate_rep_for+rep_should_for)/2
label var summ_should_for "Summary Measure: Representative Should Vote For Bill (0-100)"
gen rep_should=inthissituationdoyouthinkthesena
label var rep_should "Senator Should Vote (0 [def. not as did] - 100 [def. as did])" 

//reverse coding rep_should where needed so higher values = should do what Senator in story did
replace  rep_should=abs(inthissituationdoyouthinkthesena-100) if rep_vote=="against"
gen summ_eval_rep=(rate_rep+rep_should)/2
label var summ_eval_rep "Summary Evaluation of Senator (0-100)"

*******************************
****SAMPLE RESTRICTIONS********
*******************************
//restrict sample to cases with basic respondent characteristics (including attitude about policy used in experiment)
reg partyid educ income incomemis age r_* female region_* trt_policy, r
keep if e(sample)

//Confidm that missingness on DV not related to respondent characteristics
reg rate_rep rep_should  partyid trt_policy educ income incomemis age r_* female region_* , r
gen sample=e(sample)
//restrict sample to experiment completions
reg sample educ income incomemis age r_* female region_*  partyid 
keep if sample
//Keep only needed, properly coded variables
keep summ_eval_rep rep_should_for rate_rep rate_rep_for rep_should summ_should_for  trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree trt_rep_vote trt_rep_base trt_rep_state trt_rep_promise resp_pol_supp partyid pid3 educ income incomemis age r_* female region_* policy_* policy_cats str_polatt resp_pol_supp pol_attitude interest

***************************************
******Summary Statistics***************
***************************************
outsum summ_eval_rep rate_rep rep_should partyid educ income incomemis age r_* female region_* using "Table_A1_sumstats", replace bracket
drop r_white region_ne

***************************************
******Balance test*********************
***************************************
gen conditions_raw=trt_vote_w_base*2+trt_vote_w_state*8+trt_vote_w_promise*16+trt_policy_agree*32
egen conditions=group(conditions_raw)
drop conditions_raw
mlogit conditions  educ income incomemis age r_* female region_* partyid

***************************************
******DIRECT FX ANALYSIS***************
***************************************
reg summ_eval_rep trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* , r
test trt_vote_w_base == trt_vote_w_state
test trt_vote_w_base == trt_vote_w_promise
test trt_vote_w_base == trt_policy_agree
test trt_vote_w_promise == trt_vote_w_state
test trt_policy_agree == trt_vote_w_state
test trt_vote_w_promise == trt_policy_agree
outreg using "Table_A3_direct_FX", se bracket tdec(3) replace label 
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy) post
eststo direct_FX 

reg rate_rep trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* , r
outreg using "Table_A2_outcome", se bracket tdec(3) replace label 
reg rep_should trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* , r
outreg using "Table_A2_outcome", se bracket tdec(3) append label 

**TEST EQUALITY ACROSS POLICIES
forvalues i =1/3{
qui reg summ_eval_rep trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* if policy_cat==`i', r
disp "Policy: `i'"
disp "Policy Agree Tests"

test trt_vote_w_base == trt_policy_agree
test trt_vote_w_state== trt_policy_agree 
test trt_vote_w_promise == trt_policy_agree

disp "Base Agree Tests"
test trt_vote_w_base == trt_vote_w_state
test trt_vote_w_base == trt_vote_w_promise
disp "Promise v. State"
test trt_vote_w_promise == trt_vote_w_state
}


**indicators needed? No
foreach i in base state{
tab trt_vote_w_`i', gen(`i'_)
drop `i'_2
rename `i'_1 `i'_against
rename `i'_3 `i'_with
}

label var state_against "Vote At Odds with State (1=yes)"
label var state_with "Vote Aligned with State (1=yes)"
label var base_against "Vote At Odds with Base (1=yes)"
label var base_with "Vote Aligned with Base (1=yes)"
reg summ_eval_rep base_with  base_against state_with  state_against  trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_*, r
test base_with+base_against ==0
local base_p=r(p)
test state_with+state_against ==0
local state_p=r(p)
outreg using "Table_A3_direct_FX", se bracket tdec(3) append label adec(3) addstat("Test of Equality of Magnitude of Base PO Indicators (p)", `base_p', "Test of Equality of Magnitude of State PO Indicators (p)", r(p) )

*no demographic controls
reg summ_eval_rep trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree, r
outreg using "Table_A3_direct_FX", se bracket tdec(3) append label 

forvalues i =1/3{
reg summ_eval_rep trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* if policy_cat==`i', r
outreg using "Table_A3_direct_FX", se bracket tdec(3) append label 
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy) post
eststo direct_FX_pol_`i'

reg summ_eval_rep base_with  base_against state_with  state_against  trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* if policy_cat==`i', r
test base_with+base_against ==0
local base_p=r(p)
test state_with+state_against ==0
local state_p=r(p)
outreg using "Table_A3_direct_FX", se bracket tdec(3) append label adec(3) addstat("Test of Equality of Magnitude of Base PO Indicators (p)", `base_p', "Test of Equality of Magnitude of State PO Indicators (p)", r(p) )

reg summ_eval_rep trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree if policy_cat==`i', r
outreg using "Table_A3_direct_FX", se bracket tdec(3) append label 
}

coefplot (direct_FX, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Pooled Across Policies)) (direct_FX_pol_1, msymbol(Oh) connect(none) mcolor(gs10)  ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label(Minimum Wage)) (direct_FX_pol_2, msymbol(Sh) connect(none) mcolor(gs10)  ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label(Farm Subsidies)) (direct_FX_pol_3, msymbol(Th) connect(none) mcolor(gs10)  ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label(Transgender Bathrooms)), yline(0, lcolor(black)) level(95) ytitle("Effect on Evaluation of" "Senator's Decision (0-100)",  size(medsmall))  xtitle("Senator's Vote Aligned With...",  size(medsmall) height(7))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12)) vertical legend(region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small)) 
graph export "Figure_1_direct_FX.eps", as(eps) replace

**significance of policy interactions
reg summ_eval_rep c.trt_vote_w_base##i.policy_cat c.trt_vote_w_state##i.policy_cat  trt_vote_w_promise##i.policy_cat  trt_policy_agree##i.policy_cat partyid educ income incomemis age r_* female region_*, r

	
************************************************************
******Effects When PO and Promises Conflict? ***************
************************************************************
//table trt_vote_w_state trt_vote_w_promise if trt_vote_w_base==.5, c(mean summ_eval_rep)///
//all cases where promise/state PO conflict
reg summ_eval_rep trt_vote_w_base trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* if (trt_rep_state==1 & trt_rep_promise==0)|(trt_rep_state==0 & trt_rep_promise==1), r
outreg using "Table_A4_when_conflict", se bracket tdec(3) replace label ctitle("Promise and State PO Conflict")
//cases where promise/state PO conflict and base preferences not presented
reg summ_eval_rep trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* if ((trt_rep_state==1 & trt_rep_promise==0)|(trt_rep_state==0 & trt_rep_promise==1)) & trt_rep_base==.5, r
outreg using "Table_A4_when_conflict", se bracket tdec(3) append label ctitle("Promise and PO Conflict (Base not Presented)")
//cases where promise/state PO conflict and base/state preferences aligned
reg summ_eval_rep trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* if ((trt_rep_state==1 & trt_rep_promise==0)|(trt_rep_state==0 & trt_rep_promise==1)) & (trt_rep_base==trt_rep_state), r
outreg using "Table_A4_when_conflict", se bracket tdec(3) append label ctitle("Promise and PO Conflict (Base/State Aligned)")


************************************************************
******Promise Conditioned by Presence of PO Signal?*********
************************************************************
gen po_avail=3
replace po_avail=1 if trt_vote_w_state!=.5& trt_vote_w_base==.5
replace po_avail=2 if trt_vote_w_base!=.5 & trt_vote_w_state==.5
replace po_avail=0 if trt_vote_w_base!=.5 & trt_vote_w_state!=.5
tab po_avail, gen(p_avail_)
drop p_avail_1
label var p_avail_2 "State Opinion Only"
label var p_avail_3 "Base Opinion Only"
label var p_avail_4 "Neither PO Signal"

foreach v in trt_vote_w_promise trt_vote_w_state trt_vote_w_base trt_policy_agree{
forvalues i=2/4{
gen XX`v'Xpo_`i'=`v'*p_avail_`i'
local label : variable label `v'
local label2 : variable label p_avail_`i'
label var XX`v'Xpo_`i' "`label' x `label2'"
}
}
drop XXtrt_vote_w_stateXpo_3 XXtrt_vote_w_stateXpo_4 XXtrt_vote_w_baseXpo_2 XXtrt_vote_w_baseXpo_4

reg summ_eval_rep trt_vote_w_base trt_vote_w_state  trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* if po_avail==0, r
outreg using "Table_A6_po_avail", se bracket tdec(3) replace label 
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy) post
eststo po_avail_0

forvalues i=1/3{
reg summ_eval_rep trt_vote_w_base trt_vote_w_state  trt_vote_w_promise trt_policy_agree partyid educ income incomemis age r_* female region_* if po_avail==`i', r
outreg using "Table_A6_po_avail", se bracket tdec(3) append label 
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy) post
eststo po_avail_`i'
}
coefplot (po_avail_0, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Both Public Opinion Signals)) (po_avail_1, msymbol(Th) connect(none) mcolor(gs10)  ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label(State Opinion Only)) (po_avail_2, msymbol(Sh) connect(none) mcolor(gs10)  ciopts(lcolor(gs10) lwidth(thin) msize(vtiny)) label(Base Opinion Only)) (po_avail_3, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Neither PO Signal)), yline(0, lcolor(black)) level(95) ytitle("Effect on Evaluation of" "Senator's Decision (0-100)",  size(medsmall))  xtitle("Senator's Vote Aligned With...",  size(medsmall) height(7))  graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12)) vertical legend(region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small)) 
graph export "Figure_2_by_PO_avail.eps", as(eps) replace

reg summ_eval_rep trt_vote_w_promise trt_vote_w_state trt_vote_w_base trt_policy_agree XX* p_avail_* partyid educ income incomemis age r_* female region_*, r
test XXtrt_vote_w_promiseXpo_2 XXtrt_vote_w_promiseXpo_3 XXtrt_vote_w_promiseXpo_4
outreg using "Table_A6_po_avail", se bracket tdec(3) append label addstat("Joint sig. of Promise Interactions (p)", r(p))

//in footnote
recode po_avail (3=0) (0/2=1), gen(any_po)
reg summ_eval_rep trt_vote_w_promise##i.any_po trt_vote_w_state trt_vote_w_base trt_policy_agree##i.any_po partyid educ income incomemis age r_* female region_*, r

drop XX*

***************************************
******AGREEMENT CONDITIONALITY*********
***************************************
*mean center demographics so interaction components are for when these are at their mean 
qui sum income if incomemis==0
gen mean_income=income-r(mean)
qui sum educ 
gen mean_educ = educ-r(mean)
qui sum age 
gen mean_age = age-r(mean)
label var mean_income "Income (mean-centered)"
label var mean_age "Age (mean-centered)"
label var mean_educ "Education (mean-centered)"


//DICHOTOMOUS SUPPORT
recode resp_pol_supp (-1=0) 
label var resp_pol_supp "Respondent Supports Policy (1=yes)"
foreach v in trt_rep_base trt_rep_state trt_rep_promise {
gen `v'Xsupp=`v'*resp_pol_supp
local label : variable label `v'
label var `v'Xsupp "`label' x R Supports Policy"
}

foreach i of varlist mean_educ mean_income incomemis mean_age r_* female region_* partyid{
foreach v in trt_rep_base trt_rep_state trt_rep_promise {
gen XX`v'X`i'=`v'*`i'
local label : variable label `v'
local label2 : variable label `i'
label var XX`v'X`i' "`label' x `label2'"
}
}

reg summ_should_for trt_rep_base trt_rep_state trt_rep_promise trt_rep_baseXsupp trt_rep_stateXsupp trt_rep_promiseXsupp resp_pol_supp policy_1 policy_2 partyid mean_educ mean_income incomemis mean_age r_* female region_*, r
outreg trt_rep_base trt_rep_state trt_rep_promise trt_rep_baseXsupp trt_rep_stateXsupp trt_rep_promiseXsupp resp_pol_supp policy_1 policy_2 partyid mean_educ mean_income incomemis mean_age r_* female region_* using "Table_A5_policy_agree", se bracket tdec(3) replace label 

reg summ_should_for trt_rep_base trt_rep_state trt_rep_promise trt_rep_baseXsupp trt_rep_stateXsupp trt_rep_promiseXsupp resp_pol_supp policy_1 policy_2 partyid mean_educ mean_income incomemis mean_age r_* female region_* XX*, r
outreg trt_rep_base trt_rep_state trt_rep_promise trt_rep_baseXsupp trt_rep_stateXsupp trt_rep_promiseXsupp resp_pol_supp  policy_1 policy_2 partyid mean_educ mean_income incomemis mean_age r_* female region_* using "Table_A5_policy_agree", se bracket tdec(3) append label 

drop XX*

***************************************
******PARTY CONDITIONALITY*************
***************************************
**rebuild demographic interactions
foreach i of varlist mean_educ mean_income incomemis mean_age r_* female region_* {
foreach v in trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree{
gen XX`v'X`i'=`v'*`i'
local label : variable label `v'
local label2 : variable label `i'
label var XX`v'X`i' "`label' x `label2'"
}
}

*********************************************
***PARTY MODERATION (7 POINT SCALE) *********
*********************************************
local counter=0
local pidmod=-4
forvalues i = 1/7{
local counter=`counter'+1
local pidmod=`pidmod'+1
gen pid_`counter'=partyid-`pidmod'

foreach v in trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree{
gen `v'Xpid_`counter'=`v'*pid_`counter'
local label : variable label `v'
//note, this label indicates what PID value is set to zero (e.g., PID = 4 means the fourth point on the scale (pure ind.) is zero)
label var `v'Xpid_`counter' "`label' x PID = `counter'"
}
}

forvalues i = 1/7{
reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXpid_`i' trt_vote_w_state trt_vote_w_stateXpid_`i' trt_vote_w_promise trt_vote_w_promiseXpid_`i' trt_policy_agree trt_policy_agreeXpid_`i' pid_`i' educ income incomemis age r_* female region_* , r
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree) post
eststo party_X_`i'
}

coefplot (party_X_1, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Strong Democrats)) (party_X_7, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Strong Republicans)), yline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12) labsize(small)) vertical legend(label(2 "Estimated Effect: Strong Democrats") label (4 "Estimated Effect: Strong Republicans")  region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small))  title("Panel A: Pooled Across Policy Areas", size(medsmall))
graph save Graph "pid_pooled.gph", replace

//cycle through to get estimates for each level of PID (varying which level of PID is the reference category and pulling coefficients from component treatment variables)
forvalues i = 1/7{
forvalues p = 1/3{
reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXpid_`i' trt_vote_w_state trt_vote_w_stateXpid_`i' trt_vote_w_promise trt_vote_w_promiseXpid_`i' trt_policy_agree trt_policy_agreeXpid_`i' pid_`i' educ income incomemis age r_* female region_* if policy_cats==`p', r
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree) post
eststo party_X_`i'_pol_`p'
}
}

coefplot (party_X_1_pol_1, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Strong Democrats)) (party_X_7_pol_1, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Strong Republicans)), yline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12) labsize(small)) vertical legend(label(2 "Estimated Effect: Strong Democrats") label (4 "Estimated Effect: Strong Republicans")  region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small)) title("Panel B: Minimum Wage", size(medsmall))
graph save Graph "pid_min_wage.gph", replace
coefplot (party_X_1_pol_2, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Strong Democrats)) (party_X_7_pol_2, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Strong Republicans)), yline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12) labsize(small)) vertical legend(label(2 "Estimated Effect: Strong Democrats") label (4 "Estimated Effect: Strong Republicans")  region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small)) title("Panel C: Farm Subsidies", size(medsmall))
graph save Graph "pid_farm.gph", replace
coefplot (party_X_1_pol_3, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Strong Democrats)) (party_X_7_pol_3, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Strong Republicans)), yline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12) labsize(small)) vertical legend(label(2 "Estimated Effect: Strong Democrats") label (4 "Estimated Effect: Strong Republicans")  region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small)) title("Panel D: Transgender Bathrooms", size(medsmall))
graph save Graph "pid_tgender.gph", replace

grc1leg pid_pooled.gph pid_min_wage.gph pid_farm.gph pid_tgender.gph,   l1title("Effect on Evaluation of Senator's Decision (0-100)", size(small))   b1title("Senator's Vote Aligned With...", size(small)) cols(2) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) position(6) ring(8) ycommon 
graph export "Figure_3_pid_moderation.eps", as(eps) replace

//OUTPUT REGRESSIONS
**relabel partyID interactions
foreach v in trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree{
local label : variable label `v'
label var `v'Xpid_4 "`label' x Party Identification"
}
label var pid_4 "Party Identification (-3 = Str. Dem.; 3 = Str. Rep)"

reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXpid_4 trt_vote_w_state trt_vote_w_stateXpid_4 trt_vote_w_promise trt_vote_w_promiseXpid_4 trt_policy_agree trt_policy_agreeXpid_4 pid_4 mean_educ mean_income incomemis mean_age r_* female region_* , r
outreg using "Table_A7_party", se bracket tdec(3) replace label 
reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXpid_4 trt_vote_w_state trt_vote_w_stateXpid_4 trt_vote_w_promise trt_vote_w_promiseXpid_4 trt_policy_agree trt_policy_agreeXpid_4 pid_4 mean_educ mean_income incomemis mean_age r_* female region_* XX*, r
//outreg trt_vote_w_base trt_vote_w_baseXpid_4 trt_vote_w_state trt_vote_w_stateXpid_4 trt_vote_w_promise trt_vote_w_promiseXpid_4 trt_policy_agree trt_policy_agreeXpid_4 pid_4 mean_educ mean_income incomemis mean_age r_* female region_* using "party", se bracket tdec(3) append label 
outreg using "Table_A7_party", se bracket tdec(3) append label 

forvalues p = 1/3{
reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXpid_4 trt_vote_w_state trt_vote_w_stateXpid_4 trt_vote_w_promise trt_vote_w_promiseXpid_4 trt_policy_agree trt_policy_agreeXpid_4 pid_4 mean_educ mean_income incomemis mean_age r_* female region_* if policy_cat==`p', r
outreg using "Table_A7_party", se bracket tdec(3) append label 
reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXpid_4 trt_vote_w_state trt_vote_w_stateXpid_4 trt_vote_w_promise trt_vote_w_promiseXpid_4 trt_policy_agree trt_policy_agreeXpid_4 pid_4 mean_educ mean_income incomemis mean_age r_* female region_* XX* if policy_cat==`p', r
//outreg trt_vote_w_base trt_vote_w_baseXpid_4 trt_vote_w_state trt_vote_w_stateXpid_4 trt_vote_w_promise trt_vote_w_promiseXpid_4 trt_policy_agree trt_policy_agreeXpid_4 pid_4 mean_educ mean_income incomemis mean_age r_* female region_* using "party", se bracket tdec(3) append label 
outreg using "Table_A7_party", se bracket tdec(3) append label 
}


reg rate_rep trt_vote_w_base trt_vote_w_baseXpid_4 trt_vote_w_state trt_vote_w_stateXpid_4 trt_vote_w_promise trt_vote_w_promiseXpid_4 trt_policy_agree trt_policy_agreeXpid_4 partyid educ income incomemis age r_* female region_* , r
outreg using "Table_A2_outcome", se bracket tdec(3) append label 
reg rep_should trt_vote_w_base trt_vote_w_baseXpid_4 trt_vote_w_state trt_vote_w_stateXpid_4 trt_vote_w_promise trt_vote_w_promiseXpid_4 trt_policy_agree trt_policy_agreeXpid_4 partyid educ income incomemis age r_* female region_* , r
outreg using "Table_A2_outcome", se bracket tdec(3) append label 

*********************************************
***PARTY MODERATION (3 CATEGORY MEASURE) ****
*********************************************
tab pid3, gen(p_)
rename p_1 democrat
rename p_2 independent
rename p_3 republican
label var democrat "Democrat (1 = yes)"
label var independent "Pure Independent (1 = yes)"
label var republican "Republican (1 = yes)"
foreach v in trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree{
gen `v'Xdemocrat=`v'*democrat
gen `v'Xindependent=`v'*independent
gen `v'Xrepublican=`v'*republican
local label : variable label `v'
label var `v'Xdemocrat "`label' x Democrat"
label var `v'Xindependent "`label' x Independent"
label var `v'Xrepublican "`label' x Republican"
}
reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXdemocrat trt_vote_w_baseXindependent trt_vote_w_state trt_vote_w_stateXdemocrat trt_vote_w_stateXindependent trt_vote_w_promise trt_vote_w_promiseXdemocrat trt_vote_w_promiseXindependent trt_policy_agree trt_policy_agreeXdemocrat trt_policy_agreeXindependent democrat independent mean_educ mean_income incomemis mean_age r_* female region_* , r
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree) post
eststo republican_all

reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXrepublican trt_vote_w_baseXindependent trt_vote_w_state trt_vote_w_stateXrepublican trt_vote_w_stateXindependent trt_vote_w_promise trt_vote_w_promiseXrepublican trt_vote_w_promiseXindependent trt_policy_agree trt_policy_agreeXrepublican trt_policy_agreeXindependent republican independent mean_educ mean_income incomemis mean_age r_* female region_* , r
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree) post
eststo democrat_all

reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXrepublican trt_vote_w_baseXdemocrat trt_vote_w_state trt_vote_w_stateXrepublican trt_vote_w_stateXdemocrat trt_vote_w_promise trt_vote_w_promiseXrepublican trt_vote_w_promiseXdemocrat trt_policy_agree trt_policy_agreeXrepublican trt_policy_agreeXdemocrat republican democrat mean_educ mean_income incomemis mean_age r_* female region_* , r
outreg using "Table_A8_party3", se bracket tdec(3) replace label 
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree) post
eststo independent_all

reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXrepublican trt_vote_w_baseXdemocrat trt_vote_w_state trt_vote_w_stateXrepublican trt_vote_w_stateXdemocrat trt_vote_w_promise trt_vote_w_promiseXrepublican trt_vote_w_promiseXdemocrat trt_policy_agree trt_policy_agreeXrepublican trt_policy_agreeXdemocrat republican democrat mean_educ mean_income incomemis mean_age r_* female region_* XX*, r
outreg using "Table_A8_party3", se bracket tdec(3) append label 

reg rate_rep trt_vote_w_base trt_vote_w_baseXrepublican trt_vote_w_baseXdemocrat trt_vote_w_state trt_vote_w_stateXrepublican trt_vote_w_stateXdemocrat trt_vote_w_promise trt_vote_w_promiseXrepublican trt_vote_w_promiseXdemocrat trt_policy_agree trt_policy_agreeXrepublican trt_policy_agreeXdemocrat republican democrat educ income incomemis age r_* female region_*, r
outreg using "Table_A2_outcome", se bracket tdec(3) append label 
reg rep_should trt_vote_w_base trt_vote_w_baseXrepublican trt_vote_w_baseXdemocrat trt_vote_w_state trt_vote_w_stateXrepublican trt_vote_w_stateXdemocrat trt_vote_w_promise trt_vote_w_promiseXrepublican trt_vote_w_promiseXdemocrat trt_policy_agree trt_policy_agreeXrepublican trt_policy_agreeXdemocrat republican democrat educ income incomemis age r_* female region_*, r
outreg using "Table_A2_outcome", se bracket tdec(3) append label 

//BY POLICY AREA
forvalues p = 1/3{
reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXdemocrat trt_vote_w_baseXindependent trt_vote_w_state trt_vote_w_stateXdemocrat trt_vote_w_stateXindependent trt_vote_w_promise trt_vote_w_promiseXdemocrat trt_vote_w_promiseXindependent trt_policy_agree trt_policy_agreeXdemocrat trt_policy_agreeXindependent democrat independent mean_educ mean_income incomemis mean_age r_* female region_* if policy_cat==`p', r
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree) post
eststo republican_p_`p'

reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXrepublican trt_vote_w_baseXindependent trt_vote_w_state trt_vote_w_stateXrepublican trt_vote_w_stateXindependent trt_vote_w_promise trt_vote_w_promiseXrepublican trt_vote_w_promiseXindependent trt_policy_agree trt_policy_agreeXrepublican trt_policy_agreeXindependent republican independent mean_educ mean_income incomemis mean_age r_* female region_* if policy_cat==`p' , r
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree) post
eststo democrat_p_`p'

reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXrepublican trt_vote_w_baseXdemocrat trt_vote_w_state trt_vote_w_stateXrepublican trt_vote_w_stateXdemocrat trt_vote_w_promise trt_vote_w_promiseXrepublican trt_vote_w_promiseXdemocrat trt_policy_agree trt_policy_agreeXrepublican trt_policy_agreeXdemocrat republican democrat mean_educ mean_income incomemis mean_age r_* female region_* if policy_cat==`p' , r
outreg using "Table_A8_party3", se bracket tdec(3) append label 
margins, dydx(trt_vote_w_base trt_vote_w_state trt_vote_w_promise trt_policy_agree) post
eststo independent_p_`p'

reg summ_eval_rep trt_vote_w_base trt_vote_w_baseXrepublican trt_vote_w_baseXdemocrat trt_vote_w_state trt_vote_w_stateXrepublican trt_vote_w_stateXdemocrat trt_vote_w_promise trt_vote_w_promiseXrepublican trt_vote_w_promiseXdemocrat trt_policy_agree trt_policy_agreeXrepublican trt_policy_agreeXdemocrat republican democrat mean_educ mean_income incomemis mean_age r_* female region_* XX* if policy_cat==`p' , r
outreg using "Table_A8_party3", se bracket tdec(3) append label 
}

coefplot (democrat_all, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(All Democrats)) (independent_all, msymbol(T) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Pure Independent))  (republican_all, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Republicans)), yline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12) labsize(small)) vertical legend(label(2 "Democrats") label (4 "Pure Independents") label (6 "Republicans")  region(lcolor(white) color(none)) cols(3) colgap(10) keygap(1) size(small))  title("Panel A: Pooled Across Policy Areas", size(medsmall))
graph save Graph "pid3_pooled.gph", replace

coefplot (democrat_p_1, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(All Democrats)) (independent_p_1, msymbol(T) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Pure Independent))  (republican_p_1, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Republicans)), yline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12) labsize(small)) vertical legend(label(2 "Democrats") label (4 "Pure Independents") label (6 "Republicans")  region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small))  title("Panel B: Minimum Wage", size(medsmall))
graph save Graph "pid3_min_wage.gph", replace
coefplot (democrat_p_2, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(All Democrats)) (independent_p_2, msymbol(T) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Pure Independent))  (republican_p_2, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Republicans)), yline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12) labsize(small)) vertical legend(label(2 "Democrats") label (4 "Pure Independents") label (6 "Republicans")  region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small))  title("Panel C: Farm Subsidies", size(medsmall))
graph save Graph "pid3_farm.gph", replace
coefplot (democrat_p_3, msymbol(Oh) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(All Democrats)) (independent_p_3, msymbol(T) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Pure Independent))  (republican_p_3, msymbol(O) connect(none) mcolor(black)  ciopts(lcolor(black) lwidth(thin) msize(vtiny)) label(Republicans)), yline(0, lcolor(black)) ylabel(, labsize(small)) level(95) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large))  xscale(lw(none))  coeflabels(trt_vote_w_base  = "Base Preference" trt_vote_w_state = "State Preferences" trt_vote_w_promise = "Campaign Promise" trt_policy_agree  = "Respondent Preference", wrap(12) labsize(small)) vertical legend(label(2 "Democrats") label (4 "Pure Independents") label (6 "Republicans")  region(lcolor(white) color(none)) cols(2) colgap(10) keygap(1) size(small))  title("Panel D: Transgender Bathrooms", size(medsmall))
graph save Graph "pid3_tgender.gph", replace


grc1leg pid3_pooled.gph pid3_min_wage.gph pid3_farm.gph pid3_tgender.gph,   l1title("Effect on Evaluation of Senator's Decision (0-100)", size(small))   b1title("Senator's Vote Aligned With...", size(small)) cols(2) graphregion(fcolor(white) lcolor(none) ilcolor(none) color(white) lwidth(large)) position(6) ring(8) ycommon
graph export "Figure_4_pid3_moderation.eps", as(eps) replace

